=================
Changelog History
=================


ESMLab-regrid v2019.5.1 (2019-05-01)
===================================

- First Release
- The original code for this package came out of esmlab_ and was contained in ``esmlab.regrid`` module.


.. _esmlab: https://github.com/NCAR/esmlab


.. _`Anderson Banihirwe`: https://github.com/andersy005
.. _`Julia Kent`: https://github.com/jukent
.. _`Matthew Long`: https://github.com/matt-long
